@@ -29,7 +29,7 @@ use {
     x509_certificate::{
         asn1time::UtcTime,
         rfc5652::{Attribute, AttributeValue},
-        CapturedX509Certificate, DigestAlgorithm, InMemorySigningKeyPair, SignatureAlgorithm,
+        CapturedX509Certificate, DigestAlgorithm, Sign, SignatureAlgorithm,
     },
 };
 
@@ -40,7 +40,7 @@ use {
 #[derive(Clone)]
 pub struct SignerBuilder<'a> {
     /// The cryptographic key pair used for signing content.
-    signing_key: &'a InMemorySigningKeyPair,
+    signing_key: &'a dyn Sign,
 
     /// X.509 certificate used for signing.
     signing_certificate: CapturedX509Certificate,
@@ -69,10 +69,7 @@ impl<'a> SignerBuilder<'a> {
     /// Construct a new entity that will sign content.
     ///
     /// An entity is constructed from a signing key, which is mandatory.
-    pub fn new(
-        signing_key: &'a InMemorySigningKeyPair,
-        signing_certificate: CapturedX509Certificate,
-    ) -> Self {
+    pub fn new(signing_key: &'a dyn Sign, signing_certificate: CapturedX509Certificate) -> Self {
         Self {
             signing_key,
             signing_certificate,
@@ -85,8 +82,8 @@ impl<'a> SignerBuilder<'a> {
     }
 
     /// Obtain the signature algorithm used by the signing key.
-    pub fn signature_algorithm(&self) -> SignatureAlgorithm {
-        self.signing_key.signature_algorithm()
+    pub fn signature_algorithm(&self) -> Result<SignatureAlgorithm, CmsError> {
+        Ok(self.signing_key.signature_algorithm()?)
     }
 
     /// Define the content to use to calculate the `message-id` attribute.
@@ -303,7 +300,7 @@ impl<'a> SignedDataBuilder<'a> {
 
             let signed_attributes = Some(signed_attributes);
 
-            let signature_algorithm = signer.signature_algorithm().into();
+            let signature_algorithm = signer.signature_algorithm()?.into();
 
             // The function for computing the signed attributes digested content
             // is on SignerInfo. So construct an instance so we can compute the
